@@ -5,6 +5,7 @@ sentry.plugins.bases.tag
 :copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
+from sentry.constants import MAX_TAG_VALUE_LENGTH
 from sentry.models import Group
 from sentry.plugins import Plugin
 
@@ -24,7 +25,11 @@ class TagPlugin(Plugin):
         raise NotImplementedError
 
     def get_tags(self, event, **kwargs):
-        return [(self.tag, v) for v in self.get_tag_values(event)]
+        return [
+            (self.tag, v)
+            for v in self.get_tag_values(event)
+            if len(v) <= MAX_TAG_VALUE_LENGTH
+        ]
 
     def post_process(self, group, event, is_new, is_sample, **kwargs):
         # legacy compatibility for older plugins
